==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/OVNKubernetesConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;

 /**
  * Generated
  */
public class OVNKubernetesConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<A>{
  public OVNKubernetesConfigFluentImpl() {
  }
  public OVNKubernetesConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig instance) {
    this.withGenevePort(instance.getGenevePort()); 
    this.withHybridOverlayConfig(instance.getHybridOverlayConfig()); 
    this.withIpsecConfig(instance.getIpsecConfig()); 
    this.withMtu(instance.getMtu()); 
    this.withPolicyAuditConfig(instance.getPolicyAuditConfig()); 
  }
  private java.lang.Integer genevePort;
  private io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder hybridOverlayConfig;
  private io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder ipsecConfig;
  private java.lang.Integer mtu;
  private io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder policyAuditConfig;
  public java.lang.Integer getGenevePort() {
    return this.genevePort;
  }
  public A withGenevePort(java.lang.Integer genevePort) {
    this.genevePort=genevePort; return (A) this;
  }
  public java.lang.Boolean hasGenevePort() {
    return this.genevePort != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHybridOverlayConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig getHybridOverlayConfig() {
    return this.hybridOverlayConfig!=null?this.hybridOverlayConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig buildHybridOverlayConfig() {
    return this.hybridOverlayConfig!=null?this.hybridOverlayConfig.build():null;
  }
  public A withHybridOverlayConfig(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig hybridOverlayConfig) {
    _visitables.get("hybridOverlayConfig").remove(this.hybridOverlayConfig);
    if (hybridOverlayConfig!=null){ this.hybridOverlayConfig= new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder(hybridOverlayConfig); _visitables.get("hybridOverlayConfig").add(this.hybridOverlayConfig);} return (A) this;
  }
  public java.lang.Boolean hasHybridOverlayConfig() {
    return this.hybridOverlayConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.HybridOverlayConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfigLike(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.HybridOverlayConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editHybridOverlayConfig() {
    return withNewHybridOverlayConfigLike(getHybridOverlayConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfig() {
    return withNewHybridOverlayConfigLike(getHybridOverlayConfig() != null ? getHybridOverlayConfig(): new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfigLike(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig item) {
    return withNewHybridOverlayConfigLike(getHybridOverlayConfig() != null ? getHybridOverlayConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIpsecConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.IPsecConfig getIpsecConfig() {
    return this.ipsecConfig!=null?this.ipsecConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IPsecConfig buildIpsecConfig() {
    return this.ipsecConfig!=null?this.ipsecConfig.build():null;
  }
  public A withIpsecConfig(io.fabric8.openshift.api.model.operator.v1.IPsecConfig ipsecConfig) {
    _visitables.get("ipsecConfig").remove(this.ipsecConfig);
    if (ipsecConfig!=null){ this.ipsecConfig= new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder(ipsecConfig); _visitables.get("ipsecConfig").add(this.ipsecConfig);} return (A) this;
  }
  public java.lang.Boolean hasIpsecConfig() {
    return this.ipsecConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.IpsecConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfigLike(io.fabric8.openshift.api.model.operator.v1.IPsecConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.IpsecConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> editIpsecConfig() {
    return withNewIpsecConfigLike(getIpsecConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfig() {
    return withNewIpsecConfigLike(getIpsecConfig() != null ? getIpsecConfig(): new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfigLike(io.fabric8.openshift.api.model.operator.v1.IPsecConfig item) {
    return withNewIpsecConfigLike(getIpsecConfig() != null ? getIpsecConfig(): item);
  }
  public java.lang.Integer getMtu() {
    return this.mtu;
  }
  public A withMtu(java.lang.Integer mtu) {
    this.mtu=mtu; return (A) this;
  }
  public java.lang.Boolean hasMtu() {
    return this.mtu != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPolicyAuditConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig getPolicyAuditConfig() {
    return this.policyAuditConfig!=null?this.policyAuditConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig buildPolicyAuditConfig() {
    return this.policyAuditConfig!=null?this.policyAuditConfig.build():null;
  }
  public A withPolicyAuditConfig(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig policyAuditConfig) {
    _visitables.get("policyAuditConfig").remove(this.policyAuditConfig);
    if (policyAuditConfig!=null){ this.policyAuditConfig= new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder(policyAuditConfig); _visitables.get("policyAuditConfig").add(this.policyAuditConfig);} return (A) this;
  }
  public java.lang.Boolean hasPolicyAuditConfig() {
    return this.policyAuditConfig != null;
  }
  public A withNewPolicyAuditConfig(java.lang.String destination,java.lang.Integer maxFileSize,java.lang.Integer rateLimit,java.lang.String syslogFacility) {
    return (A)withPolicyAuditConfig(new PolicyAuditConfig(destination, maxFileSize, rateLimit, syslogFacility));
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.PolicyAuditConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfigLike(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.PolicyAuditConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editPolicyAuditConfig() {
    return withNewPolicyAuditConfigLike(getPolicyAuditConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfig() {
    return withNewPolicyAuditConfigLike(getPolicyAuditConfig() != null ? getPolicyAuditConfig(): new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfigLike(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig item) {
    return withNewPolicyAuditConfigLike(getPolicyAuditConfig() != null ? getPolicyAuditConfig(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OVNKubernetesConfigFluentImpl that = (OVNKubernetesConfigFluentImpl) o;
    if (genevePort != null ? !genevePort.equals(that.genevePort) :that.genevePort != null) return false;
    if (hybridOverlayConfig != null ? !hybridOverlayConfig.equals(that.hybridOverlayConfig) :that.hybridOverlayConfig != null) return false;
    if (ipsecConfig != null ? !ipsecConfig.equals(that.ipsecConfig) :that.ipsecConfig != null) return false;
    if (mtu != null ? !mtu.equals(that.mtu) :that.mtu != null) return false;
    if (policyAuditConfig != null ? !policyAuditConfig.equals(that.policyAuditConfig) :that.policyAuditConfig != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(genevePort,  hybridOverlayConfig,  ipsecConfig,  mtu,  policyAuditConfig,  super.hashCode());
  }
  public class HybridOverlayConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HybridOverlayConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder(this, item);
    }
    HybridOverlayConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder builder;
    public N and() {
      return (N) OVNKubernetesConfigFluentImpl.this.withHybridOverlayConfig(builder.build());
    }
    public N endHybridOverlayConfig() {
      return and();
    }
    
  }
  public class IpsecConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.IPsecConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IpsecConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.IPsecConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder(this, item);
    }
    IpsecConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder builder;
    public N and() {
      return (N) OVNKubernetesConfigFluentImpl.this.withIpsecConfig(builder.build());
    }
    public N endIpsecConfig() {
      return and();
    }
    
  }
  public class PolicyAuditConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PolicyAuditConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder(this, item);
    }
    PolicyAuditConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder builder;
    public N and() {
      return (N) OVNKubernetesConfigFluentImpl.this.withPolicyAuditConfig(builder.build());
    }
    public N endPolicyAuditConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/OVNKubernetesConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class OVNKubernetesConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<A>{
  public OVNKubernetesConfigFluentImpl() {
  }
  public OVNKubernetesConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig instance) {
    this.withGenevePort(instance.getGenevePort()); 
    this.withHybridOverlayConfig(instance.getHybridOverlayConfig()); 
    this.withIpsecConfig(instance.getIpsecConfig()); 
    this.withMtu(instance.getMtu()); 
    this.withPolicyAuditConfig(instance.getPolicyAuditConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer genevePort;
  private io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder hybridOverlayConfig;
  private io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder ipsecConfig;
  private java.lang.Integer mtu;
  private io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder policyAuditConfig;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getGenevePort() {
    return this.genevePort;
  }
  public A withGenevePort(java.lang.Integer genevePort) {
    this.genevePort=genevePort; return (A) this;
  }
  public java.lang.Boolean hasGenevePort() {
    return this.genevePort != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHybridOverlayConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig getHybridOverlayConfig() {
    return this.hybridOverlayConfig!=null?this.hybridOverlayConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig buildHybridOverlayConfig() {
    return this.hybridOverlayConfig!=null?this.hybridOverlayConfig.build():null;
  }
  public A withHybridOverlayConfig(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig hybridOverlayConfig) {
    _visitables.get("hybridOverlayConfig").remove(this.hybridOverlayConfig);
    if (hybridOverlayConfig!=null){ this.hybridOverlayConfig= new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder(hybridOverlayConfig); _visitables.get("hybridOverlayConfig").add(this.hybridOverlayConfig);} return (A) this;
  }
  public java.lang.Boolean hasHybridOverlayConfig() {
    return this.hybridOverlayConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.HybridOverlayConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfigLike(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.HybridOverlayConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editHybridOverlayConfig() {
    return withNewHybridOverlayConfigLike(getHybridOverlayConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfig() {
    return withNewHybridOverlayConfigLike(getHybridOverlayConfig() != null ? getHybridOverlayConfig(): new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfigLike(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig item) {
    return withNewHybridOverlayConfigLike(getHybridOverlayConfig() != null ? getHybridOverlayConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIpsecConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.IPsecConfig getIpsecConfig() {
    return this.ipsecConfig!=null?this.ipsecConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IPsecConfig buildIpsecConfig() {
    return this.ipsecConfig!=null?this.ipsecConfig.build():null;
  }
  public A withIpsecConfig(io.fabric8.openshift.api.model.operator.v1.IPsecConfig ipsecConfig) {
    _visitables.get("ipsecConfig").remove(this.ipsecConfig);
    if (ipsecConfig!=null){ this.ipsecConfig= new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder(ipsecConfig); _visitables.get("ipsecConfig").add(this.ipsecConfig);} return (A) this;
  }
  public java.lang.Boolean hasIpsecConfig() {
    return this.ipsecConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.IpsecConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfigLike(io.fabric8.openshift.api.model.operator.v1.IPsecConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.IpsecConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> editIpsecConfig() {
    return withNewIpsecConfigLike(getIpsecConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfig() {
    return withNewIpsecConfigLike(getIpsecConfig() != null ? getIpsecConfig(): new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfigLike(io.fabric8.openshift.api.model.operator.v1.IPsecConfig item) {
    return withNewIpsecConfigLike(getIpsecConfig() != null ? getIpsecConfig(): item);
  }
  public java.lang.Integer getMtu() {
    return this.mtu;
  }
  public A withMtu(java.lang.Integer mtu) {
    this.mtu=mtu; return (A) this;
  }
  public java.lang.Boolean hasMtu() {
    return this.mtu != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPolicyAuditConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig getPolicyAuditConfig() {
    return this.policyAuditConfig!=null?this.policyAuditConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig buildPolicyAuditConfig() {
    return this.policyAuditConfig!=null?this.policyAuditConfig.build():null;
  }
  public A withPolicyAuditConfig(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig policyAuditConfig) {
    _visitables.get("policyAuditConfig").remove(this.policyAuditConfig);
    if (policyAuditConfig!=null){ this.policyAuditConfig= new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder(policyAuditConfig); _visitables.get("policyAuditConfig").add(this.policyAuditConfig);} return (A) this;
  }
  public java.lang.Boolean hasPolicyAuditConfig() {
    return this.policyAuditConfig != null;
  }
  public A withNewPolicyAuditConfig(java.lang.String destination,java.lang.Integer maxFileSize,java.lang.Integer rateLimit,java.lang.String syslogFacility) {
    return (A)withPolicyAuditConfig(new PolicyAuditConfig(destination, maxFileSize, rateLimit, syslogFacility));
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.PolicyAuditConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfigLike(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl.PolicyAuditConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editPolicyAuditConfig() {
    return withNewPolicyAuditConfigLike(getPolicyAuditConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfig() {
    return withNewPolicyAuditConfigLike(getPolicyAuditConfig() != null ? getPolicyAuditConfig(): new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfigLike(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig item) {
    return withNewPolicyAuditConfigLike(getPolicyAuditConfig() != null ? getPolicyAuditConfig(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OVNKubernetesConfigFluentImpl that = (OVNKubernetesConfigFluentImpl) o;
    if (genevePort != null ? !genevePort.equals(that.genevePort) :that.genevePort != null) return false;
    if (hybridOverlayConfig != null ? !hybridOverlayConfig.equals(that.hybridOverlayConfig) :that.hybridOverlayConfig != null) return false;
    if (ipsecConfig != null ? !ipsecConfig.equals(that.ipsecConfig) :that.ipsecConfig != null) return false;
    if (mtu != null ? !mtu.equals(that.mtu) :that.mtu != null) return false;
    if (policyAuditConfig != null ? !policyAuditConfig.equals(that.policyAuditConfig) :that.policyAuditConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(genevePort,  hybridOverlayConfig,  ipsecConfig,  mtu,  policyAuditConfig,  additionalProperties,  super.hashCode());
  }
  public class HybridOverlayConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.HybridOverlayConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HybridOverlayConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder(this, item);
    }
    HybridOverlayConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.HybridOverlayConfigBuilder builder;
    public N and() {
      return (N) OVNKubernetesConfigFluentImpl.this.withHybridOverlayConfig(builder.build());
    }
    public N endHybridOverlayConfig() {
      return and();
    }
    
  }
  public class IpsecConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.IPsecConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.IpsecConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IpsecConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.IPsecConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder(this, item);
    }
    IpsecConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.IPsecConfigBuilder builder;
    public N and() {
      return (N) OVNKubernetesConfigFluentImpl.this.withIpsecConfig(builder.build());
    }
    public N endIpsecConfig() {
      return and();
    }
    
  }
  public class PolicyAuditConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent.PolicyAuditConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PolicyAuditConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder(this, item);
    }
    PolicyAuditConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigBuilder builder;
    public N and() {
      return (N) OVNKubernetesConfigFluentImpl.this.withPolicyAuditConfig(builder.build());
    }
    public N endPolicyAuditConfig() {
      return and();
    }
    
  }
  
}
